==> reference1-1.0-sources.jar: one/xingyi/reference1/person/client/view/PersonLine12ViewDebugInfo.java <==
package one.xingyi.reference1.person.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference1.person.IPersonLine12ViewDefn
import java.lang.String;
public class PersonLine12ViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference1.person.IPersonLine12ViewDefn
    Entity:     one.xingyi.reference1.person.client.entitydefn.IPersonLine12ViewClientEntity
    View:        one.xingyi.reference1.person.client.view.PersonLine12View
    Impl   :    one.xingyi.reference1.person.client.view.PersonLine12ViewImpl
    ServerImpl: one.xingyi.reference1.person.client.viewcompanion.PersonLine12ViewCompanion
    Original: one.xingyi.reference1.person.IPersonDefn
        IServer:    one.xingyi.reference1.person.server.domain.IPerson
        ServerImpl: one.xingyi.reference1.person.server.domain.Person
        Client:     one.xingyi.reference1.person.client.entitydefn.IPersonClientEntity
        ServComp:   one.xingyi.reference1.person.server.companion.PersonCompanion
        Lens:       Person
Fields: 2
    Field: line1
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('line2');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference1.person.IPersonDefn
    IServer:    one.xingyi.reference1.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference1.person.server.domain.Person
    Client:     one.xingyi.reference1.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference1.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 5
    Field: name
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   false
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: age
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=Integer))
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: line1
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line1/String
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line2/String
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference1.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference1.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference1.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference1.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional[PrototypeDom(prototypeId=prototype)]
prototypeNoId: Optional.empty
Posts:         []
*/}

==> reference1-1.1-sources.jar: one/xingyi/reference1/person/client/view/PersonLine12ViewDebugInfo.java <==
package one.xingyi.reference1.person.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference1.person.IPersonLine12ViewDefn
import java.lang.String;
public class PersonLine12ViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference1.person.IPersonLine12ViewDefn
    Entity:     one.xingyi.reference1.person.client.entitydefn.IPersonLine12ViewClientEntity
    View:        one.xingyi.reference1.person.client.view.PersonLine12View
    Impl   :    one.xingyi.reference1.person.client.view.PersonLine12ViewImpl
    ServerImpl: one.xingyi.reference1.person.client.viewcompanion.PersonLine12ViewCompanion
    Original: one.xingyi.reference1.person.IPersonDefn
        IServer:    one.xingyi.reference1.person.server.domain.IPerson
        ServerImpl: one.xingyi.reference1.person.server.domain.Person
        Client:     one.xingyi.reference1.person.client.entitydefn.IPersonClientEntity
        ServComp:   one.xingyi.reference1.person.server.companion.PersonCompanion
        Lens:       Person
Fields: 2
    Field: line1
        StringPrimitiveType()
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        StringPrimitiveType()
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('line2');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference1.person.IPersonDefn
    IServer:    one.xingyi.reference1.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference1.person.server.domain.Person
    Client:     one.xingyi.reference1.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference1.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 5
    Field: name
        StringPrimitiveType()
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   false
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: age
        IntegerPrimitiveType()
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: line1
        StringPrimitiveType()
        Lens path  line1/String
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        StringPrimitiveType()
        Lens path  line2/String
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference1.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference1.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference1.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference1.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference1.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional[PrototypeDom(prototypeId=prototype)]
prototypeNoId: Optional.empty
Posts:         []
*/}
